var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import path from 'path';
import { describe, it } from 'mocha';
import { expect } from 'chai';
import { execa } from 'execa';
const __dirname = new URL('.', import.meta.url).pathname;
describe('babel-register-esm (e2e)', function () {
    it('should run a file unchanged if no plugins', () => __awaiter(this, void 0, void 0, function* () {
        const result = yield executeFileWithLoader('simple', 'nochange.js');
        expect(result.all).to.equal('hi');
    }));
    it('should work with JSX', () => __awaiter(this, void 0, void 0, function* () {
        const result = yield executeFileWithLoader('jsx', 'jsx.js');
        expect(result.all).to.equal('button');
    }));
    it('should work with JSX in a .jsx file', () => __awaiter(this, void 0, void 0, function* () {
        const result = yield executeFileWithLoader('jsx', 'jsx.jsx');
        expect(result.all).to.equal('button');
    }));
    it('should work with TypeScript', () => __awaiter(this, void 0, void 0, function* () {
        const result = yield executeFileWithLoader('typescript', 'ts.ts');
        expect(result.all).to.equal('hi');
    }));
    it('should work with TypeScript TSX', () => __awaiter(this, void 0, void 0, function* () {
        const result = yield executeFileWithLoader('typescript', 'ts2.tsx');
        expect(result.all).to.equal('hi\nbutton');
    }));
    it('should work with TypeScript TSX, importing a url with query params', () => __awaiter(this, void 0, void 0, function* () {
        const result = yield executeFileWithLoader('typescript-with-query-params', 'ts2.tsx');
        expect(result.all).to.equal('hi\nbutton');
    }));
    it('should ignore ignored files', () => __awaiter(this, void 0, void 0, function* () {
        expect(yield executeFileWithLoader('jsx', 'ignored.js').catch((error) => error.message)).to.include('SyntaxError');
    }));
    it('should lookup babel rc files upward', () => __awaiter(this, void 0, void 0, function* () {
        expect((yield executeFileWithLoader('subfolders/sub', 'jsx.js')).all).to.equal('button');
    }));
    it('should support all kinds of babelrc files, not just json', () => __awaiter(this, void 0, void 0, function* () {
        expect((yield executeFileWithLoader('babelrcjs', 'jsx.js')).all).to.equal('button');
    }));
    it('should support non-file imports', () => __awaiter(this, void 0, void 0, function* () {
        expect((yield executeFileWithLoader('non-file', 'jsx.js')).all).to.equal('button');
    }));
});
/**
 * @param {string} fixture
 * @param {string} file
 */
function executeFileWithLoader(fixture, file) {
    return __awaiter(this, void 0, void 0, function* () {
        return yield execa('node', ['--no-warnings', '--loader', path.resolve(__dirname, '../../src/babel-register-esm.js'), file], { all: true, cwd: path.resolve(__dirname, 'fixtures', fixture) });
    });
}
//# sourceMappingURL=babel-register-esm.e2e.test.js.map